@@ -146,7 +146,7 @@ private:
 #endif // !G_OS_WIN32
 
 public:
-  typedef sigc::signal<void> SignalFinished;
+  typedef sigc::signal<void()> SignalFinished;
 
   /** TODO: Document the redirect parameter.
    */
@@ -188,7 +188,7 @@ public:
       std::vector<std::string> arguments = Glib::shell_parse_argv(command_line);
       int child_stdout = 0;
       int child_stderr = 0;
-      Glib::spawn_async_with_pipes(Glib::get_current_dir(), arguments, Glib::SPAWN_DO_NOT_REAP_CHILD, sigc::slot<void>(), &pid, 0, (redirect & REDIRECT_STDOUT) ? &child_stdout : 0, (redirect & REDIRECT_STDERR) ? &child_stderr : 0);
+      Glib::spawn_async_with_pipes(Glib::get_current_dir(), arguments, Glib::SPAWN_DO_NOT_REAP_CHILD, sigc::slot<void()>(), &pid, 0, (redirect & REDIRECT_STDOUT) ? &child_stdout : 0, (redirect & REDIRECT_STDERR) ? &child_stderr : 0);
       if(redirect & REDIRECT_STDOUT)
         redirect_to_string(child_stdout, stdout_text);
       if(redirect & REDIRECT_STDERR)
@@ -342,7 +342,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
   //Show UI progress feedback while we wait for the command to finish:
 
   std::shared_ptr<const Impl::SpawnInfo> info;
-  
+
   try
   {
     info = Impl::spawn_async(command, 0);
@@ -386,7 +386,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
   //Show UI progress feedback while we wait for the command to finish:
 
   std::shared_ptr<const Impl::SpawnInfo> info;
-  
+
   try
   {
     info = Impl::spawn_async(command, Impl::REDIRECT_STDOUT | Impl::REDIRECT_STDERR);
@@ -396,7 +396,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
     std::cerr << G_STRFUNC << ": exception: " << ex.what() << std::endl;
     return false;
   }
-  
+
 
   auto mainloop = Glib::MainLoop::create(false);
   info->signal_finished().connect(
@@ -561,7 +561,7 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
     std::cerr << G_STRFUNC << ": exception: " << ex.what() << std::endl;
     return false;
   }
-  
+
   // While we wait for the second command to finish we
   // a) check whether the first command finished. If it did, and has a
   // negative error code, we assume it failed and return directly.
