@@ -25,11 +25,12 @@
 #include <glom/utils_ui.h>
 #include <libglom/data_structure/layout/layoutitem_field.h>
 #include <libglom/db_utils.h>
+#include <libglom/layout_utils.h>
 #include <libglom/privs.h>
 #include <glom/python_embed/glom_python.h>
 #include <glom/python_embed/python_ui_callbacks.h>
 #include <glom/appwindow.h>
-#include <libglom/libglom_config.h>
+#include <libglom/utils.h>
 #include <iostream>
 #include <glibmm/i18n.h>
 
@@ -40,7 +41,7 @@ namespace Glom
 Box_Data::Box_Data()
 : m_Button_Find(_("_Find"), true)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  ,m_pDialogLayout(nullptr)
+  ,m_dialog_layout(nullptr)
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 {
   m_bUnstoredData = false;
@@ -52,10 +53,10 @@ Box_Data::Box_Data()
 Box_Data::~Box_Data()
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  if(m_pDialogLayout)
+  if(m_dialog_layout)
   {
-    remove_view(m_pDialogLayout);
-    delete m_pDialogLayout;
+    remove_view(m_dialog_layout);
+    delete m_dialog_layout;
   }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
@@ -155,9 +156,9 @@ void Box_Data::on_Button_Find()
   signal_find_criteria.emit(where_clause);
 }
 
-void Box_Data::set_unstored_data(bool bVal)
+void Box_Data::set_unstored_data(bool value)
 {
-  m_bUnstoredData = bVal;
+  m_bUnstoredData = value;
 }
 
 bool Box_Data::get_unstored_data() const
@@ -203,15 +204,15 @@ bool Box_Data::confirm_discard_unstored_data() const
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Data::show_layout_dialog()
 {
-  if(!m_pDialogLayout)
+  if(!m_dialog_layout)
   {
-    m_pDialogLayout = create_layout_dialog();
-    add_view(m_pDialogLayout); //Give it access to the document.
-    m_pDialogLayout->signal_hide().connect( sigc::mem_fun(*this, &Box_Data::on_dialog_layout_hide) );
+    m_dialog_layout = create_layout_dialog();
+    add_view(m_dialog_layout); //Give it access to the document.
+    m_dialog_layout->signal_hide().connect( sigc::mem_fun(*this, &Box_Data::on_dialog_layout_hide) );
   }
 
-  prepare_layout_dialog(m_pDialogLayout);
-  m_pDialogLayout->show();
+  prepare_layout_dialog(m_dialog_layout);
+  m_dialog_layout->show();
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -241,8 +242,11 @@ Box_Data::type_vecConstLayoutFields Box_Data::get_table_fields_to_show(const Gli
   const auto pDoc = std::dynamic_pointer_cast<const Document>(get_document());
   if(pDoc)
   {
-    Document::type_list_layout_groups mapGroupSequence = pDoc->get_data_layout_groups_plus_new_fields(m_layout_name, table_name, m_layout_platform);
-    return Utils::get_table_fields_to_show_for_sequence(pDoc, table_name, mapGroupSequence);
+    const auto mapGroupSequence = pDoc->get_data_layout_groups_plus_new_fields(m_layout_name, table_name, m_layout_platform);
+
+    //TODO: Avoid the copy just for the constness.
+    const auto const_sequence = Utils::const_list(mapGroupSequence);
+    return Utils::get_table_fields_to_show_for_sequence(pDoc, table_name, const_sequence);
   }
   else
     return type_vecConstLayoutFields();
