@@ -52,7 +52,7 @@ public:
 
   void set_choices_fixed(const Formatting::type_list_values& list_values, bool restricted = false) override;
 
-  void set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value) override;
+  void set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value) override;
 
   void set_read_only(bool read_only = true) override;
 
@@ -69,7 +69,6 @@ public:
   Gnome::Gda::Value get_value() const override;
 
 private:
-  void init();
 
   typedef std::vector<Gnome::Gda::Value> type_list_values;
   typedef std::vector< std::pair<Gnome::Gda::Value, type_list_values> > type_list_values_with_second;
