@@ -103,7 +103,7 @@ public:
    */
   void set_other_field_value(const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& value);
 
-  /** Refresh the list of related records in choice combo boxes, 
+  /** Refresh the list of related records in choice combo boxes,
    * in any instance of the specified field.
    */
   void update_choices(const std::shared_ptr<const LayoutItem_Field>& field);
@@ -136,44 +136,44 @@ public:
    */
   void get_layout_groups(Document::type_list_layout_groups& groups);
   std::shared_ptr<LayoutGroup> get_layout_group();
-  
+
   void set_enable_drag_and_drop(bool enabled = true);
 
   /** For instance,
    * void on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
    */
-  typedef sigc::signal<void, const std::shared_ptr<const LayoutItem_Field>&, const Gnome::Gda::Value&> type_signal_field_edited;
+  typedef sigc::signal<void(const std::shared_ptr<const LayoutItem_Field>&, const Gnome::Gda::Value&)> type_signal_field_edited;
   type_signal_field_edited signal_field_edited();
 
   /** For instance,
    * void on_flowtable_field_choices_changed(const std::shared_ptr<const LayoutItem_Field>& field);
    */
-  typedef sigc::signal<void, const std::shared_ptr<const LayoutItem_Field>&> type_signal_field_choices_changed;
+  typedef sigc::signal<void(const std::shared_ptr<const LayoutItem_Field>&)> type_signal_field_choices_changed;
   type_signal_field_choices_changed signal_field_choices_changed();
 
 
   /** For instance,
    * void on_flowtable_field_open_details_requested(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
    */
-  typedef sigc::signal<void, const std::shared_ptr<const LayoutItem_Field>&, const Gnome::Gda::Value&> type_signal_field_open_details_requested;
+  typedef sigc::signal<void(const std::shared_ptr<const LayoutItem_Field>&, const Gnome::Gda::Value&)> type_signal_field_open_details_requested;
   type_signal_field_open_details_requested signal_field_open_details_requested();
 
   /** For instance,
    * void on_related_record_changed(const Glib::ustring& relationship_name);
    */
-  typedef sigc::signal<void, const Glib::ustring&> type_signal_related_record_changed;
+  typedef sigc::signal<void(const Glib::ustring&)> type_signal_related_record_changed;
   type_signal_related_record_changed signal_related_record_changed();
 
   /** For instance,
    * void on_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
    */
-  typedef sigc::signal<void, const Glib::ustring&, Gnome::Gda::Value> type_signal_requested_related_details;
+  typedef sigc::signal<void(const Glib::ustring&, Gnome::Gda::Value)> type_signal_requested_related_details;
   type_signal_requested_related_details signal_requested_related_details();
 
  /** For instance,
    * void on_script_button_clicked(const std::shared_ptr<LayoutItem_Button>& layout_item>);
    */
-  typedef sigc::signal<void, const std::shared_ptr<LayoutItem_Button>&> type_signal_script_button_clicked;
+  typedef sigc::signal<void(const std::shared_ptr<LayoutItem_Button>&)> type_signal_script_button_clicked;
   type_signal_script_button_clicked signal_script_button_clicked();
 
 private:
