@@ -19,7 +19,6 @@
  */
 
 #include <glom/mode_design/report_layout/dialog_layout_report.h>
-#include <libglom/data_structure/layout/report_parts/layoutitem_groupby.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_summary.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_verticalgroup.h>
@@ -38,7 +37,6 @@
 //#include <libgnome/gnome-i18n.h>
 #include <libglom/utils.h> //For bold_message()).
 #include <glibmm/i18n.h>
-#include <sstream> //For stringstream
 
 namespace Glom
 {
@@ -725,8 +723,7 @@ Gtk::TreeModel::iterator Dialog_Layout_Report::get_selected_group_parent() const
   if(!treeview)
     return parent;
 
-  Glib::RefPtr<const type_model> model = get_selected_model();
-
+  auto model = get_selected_model();
 
   auto refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
