@@ -238,7 +238,7 @@ void Dialog_GroupsList::on_button_group_new()
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
-    
+
   dialog->set_transient_for(*this);
   const auto dialog_response = Glom::UiUtils::dialog_run_with_help(dialog);
 
@@ -280,7 +280,7 @@ void Dialog_GroupsList::on_button_group_users()
       Utils::get_glade_widget_derived_with_warning(dialog);
       if(!dialog) //Unlikely and it already warns on stderr.
         return;
-    
+
       dialog->set_transient_for(*this);
       add_view(dialog); //Give it access to the document.
 
@@ -422,7 +422,7 @@ void Dialog_GroupsList::load_from_document()
   //fill_table_list();
 }
 
-void Dialog_GroupsList::treeview_append_bool_column(Gtk::TreeView& treeview, const Glib::ustring& title, Gtk::TreeModelColumn<bool>& model_column, const sigc::slot<void,  const Glib::ustring&>& slot_toggled)
+void Dialog_GroupsList::treeview_append_bool_column(Gtk::TreeView& treeview, const Glib::ustring& title, Gtk::TreeModelColumn<bool>& model_column, const sigc::slot<void(const Glib::ustring&)>& slot_toggled)
 {
   auto pCellRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
 
