@@ -2,6 +2,7 @@
 #include <glom/libglom/connectionpool.h>
 #include <glom/python_embed/glom_python.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/file_utils.h>
 #include <libglom/utils.h>
 #include <glibmm/convert.h>
 #include <glibmm/miscutils.h>
@@ -37,7 +38,7 @@ int main()
 
   try
   {
-    const std::string path =
+    const auto path =
        Glib::build_filename(GLOM_DOCDIR_EXAMPLES_NOTINSTALLED,
          "sqlite", "test_sqlite_music", "test_sqlite_music.glom");
     uri = Glib::filename_to_uri(path);
@@ -48,7 +49,7 @@ int main()
     return EXIT_FAILURE;
   }
 
-  g_assert( Glom::Utils::file_exists(uri) );
+  g_assert( Glom::FileUtils::file_exists(uri) );
   //std::cout << "URI=" << uri << std::endl;
 
 
@@ -71,7 +72,7 @@ int main()
   connection_pool->setup_from_document(document);
 
   //This is not really necessary for sqlite-based databases.
-  const Glom::ConnectionPool::StartupErrors started =
+  const auto started =
     connection_pool->startup( sigc::ptr_fun(&on_startup_progress) );
   if(started != Glom::ConnectionPool::Backend::StartupErrors::NONE)
   {
